@@ -1345,7 +1345,7 @@ class ExtendedModel(AbstractObject):
         df = variable_collection_to_dataframe(vcollection)
         return df    
     
-    def print_summary(self, items:Optional[List]=None, suppress_print:bool=False,
+    def print_summary(self, items:Optional[List]=None, suppress_print:bool=False, detailed:bool=True,
                       include_patterns:Optional[List]=None, exclude_patterns:Optional[List]=None,
                       save_as:Optional[str]=None):
         if items is None:
@@ -1394,14 +1394,21 @@ class ExtendedModel(AbstractObject):
                 pset = [p for pattern in include_patterns for p in pset if fnmatch.fnmatch(p.GetName(), pattern)]
             if exclude_patterns is not None:
                 pset = [p for pattern in exclude_patterns for p in pset if not fnmatch.fnmatch(p.GetName(), pattern)]
-            for p in pset:
-                name   = p.GetName()
-                value  = p.getVal()
-                vrange = p.getRange()
-                vmin   = vrange[0]
-                vmax   = vrange[1]
-                const_str = "C" if p.isConstant() else "F"
-                summary_str += f"\t{name} = {value} [{vmin}, {vmax}] {const_str}\n"
+                
+            data = [get_variable_attributes(p) for p in pset]
+            data = sorted(data, key=lambda d: d['name'])
+            if detailed:
+                for d in data:
+                    name   = d['name']
+                    value  = d['value']
+                    vmin   = d['min']
+                    vmax   = d['max']
+                    const_str = "C" if d['is_constant'] else "F"
+                    summary_str += f"\t{name} = {value} [{vmin}, {vmax}] {const_str}\n"
+            else:
+                for d in data:
+                    name = d['name']
+                    summary_str += f"\t{name}\n"
         if not suppress_print:
             print(summary_str)
         if save_as is not None:
