@@ -129,7 +129,7 @@ class UpperLimit2DPlot(AbstractPlot):
                                       label=labels['expected'],
                                       alpha=alpha)
         else:
-            handle_observed = None
+            handle_observed = [None]
             handle_expected = draw_fn(indices, exp_limits, color=color_pallete['expected'],
                                       label=labels['expected'],
                                       alpha=alpha)
@@ -193,8 +193,12 @@ class UpperLimit2DPlot(AbstractPlot):
             primary_labels  = [labels[handles.index(h)] for h in [h_exp, h_1sig, h_2sig]]
         
         if self.data_sec is not None:
-            secondary_handles = [h_obs_sec, h_exp2_sec, (h_1sig2_sec, border_leg), (h_2sig_sec, border_leg)]
-            secondary_labels  = [labels[handles.index(h)] for h in [h_obs_sec, h_exp2_sec, h_1sig2_sec, h_2sig_sec]]
+            if draw_observed:
+                secondary_handles = [h_obs_sec, h_exp2_sec, (h_1sig2_sec, border_leg), (h_2sig_sec, border_leg)]
+                secondary_labels  = [labels[handles.index(h)] for h in [h_obs_sec, h_exp2_sec, h_1sig2_sec, h_2sig_sec]]
+            else:
+                secondary_handles = [h_exp2_sec, (h_1sig2_sec, border_leg), (h_2sig_sec, border_leg)]
+                secondary_labels  = [labels[handles.index(h)] for h in [h_exp2_sec, h_1sig2_sec, h_2sig_sec]]
         else:
             secondary_handles = []
             secondary_labels = []
